==> eiffelstudio-18.11.10.2592.tar: F_code/C6/as267.c <==
/*
 * Code for class AST_FORMAL_GENERICS_PASS2
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "as267.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {AST_FORMAL_GENERICS_PASS2}.make */
void F317_4751 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,arg2);
	RTLR(3,arg3);
	RTLIU(4);
	
	RTEAA("make", 316, Current, 0, 3, 4623);
	RTGC;
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	RTAR(Current, arg2);
	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) arg2;
	RTHOOK(3);
	RTAR(Current, arg3);
	*(EIF_REFERENCE *)(Current + _REFACS_4_) = (EIF_REFERENCE) arg3;
	RTHOOK(7);
	RTLE;
	RTEE;
}

/* {AST_FORMAL_GENERICS_PASS2}.has_node_changed */
EIF_BOOLEAN F317_4752 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("has_node_changed", 316, Current, 0, 0, 4624);
	RTHOOK(1);
	RTHOOK(2);
	RTEE;
	return (EIF_BOOLEAN) (EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current + _REFACS_1_) != NULL);
}

/* {AST_FORMAL_GENERICS_PASS2}.consume_node */
void F317_4753 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("consume_node", 316, Current, 0, 0, 4625);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) NULL;
	RTHOOK(5);
	RTLE;
	RTEE;
}

/* {AST_FORMAL_GENERICS_PASS2}.last_consumed_node */
EIF_REFERENCE F317_4754 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {AST_FORMAL_GENERICS_PASS2}.new_node */
EIF_REFERENCE F317_4755 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {AST_FORMAL_GENERICS_PASS2}.ast_factory */
EIF_REFERENCE F317_4756 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


/* {AST_FORMAL_GENERICS_PASS2}.suppliers */
EIF_REFERENCE F317_4757 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_3_);
}


/* {AST_FORMAL_GENERICS_PASS2}.formal_parameters */
EIF_REFERENCE F317_4758 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_4_);
}


/* {AST_FORMAL_GENERICS_PASS2}.process_formal_as */
void F317_4759 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("process_formal_as", 316, Current, 0, 1, 4631);
	RTGC;
	
	RTHOOK(2);
	RTLE;
	RTEE;
}

/* {AST_FORMAL_GENERICS_PASS2}.process_class_type_as */
void F317_4760 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN tb3;
	EIF_BOOLEAN tb4;
	EIF_BOOLEAN tb5;
	RTLD;
	
	RTLI(8);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,loc4);
	RTLR(3,tr1);
	RTLR(4,Current);
	RTLR(5,loc5);
	RTLR(6,loc2);
	RTLR(7,loc3);
	RTLIU(8);
	
	RTEAA("process_class_type_as", 316, Current, 5, 1, 4632);
	RTGC;
	
	RTHOOK(2);
	loc1 = *(EIF_REFERENCE *)(RTCW(arg1));
	RTHOOK(3);
	tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R13256[Dtype(arg1)-1420])(RTCW(arg1));
	loc4 = tr1;
	if (EIF_TEST(loc4)) {
		RTHOOK(4);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
		F53_778(RTCW(tr1), loc1);
		RTHOOK(5);
		F924_7773(loc4);
		for (;;) {
			RTHOOK(6);
			tb1 = F888_7590(loc4);
			if (tb1) break;
			RTHOOK(7);
			tr1 = F924_7747(loc4);
			(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R12746[Dtype(tr1)-1349])(RTCW(tr1), Current);
			RTHOOK(8);
			if (F317_4752(Current)) {
				RTHOOK(9);
				F317_4753(Current);
				RTHOOK(10);
				tr1 = *(EIF_REFERENCE *)(Current);
				loc5 = tr1;
				if (EIF_TEST(loc5)) {
					RTHOOK(11);
					F924_7786(loc4, loc5);
				}
				
			}
			RTHOOK(13);
			F924_7775(loc4);
		}
	} else {
		RTHOOK(14);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
		F924_7773(RTCW(tr1));
		for (;;) {
			RTHOOK(15);
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
			tb2 = F888_7590(RTCW(tr1));
			if (tb2) break;
			RTHOOK(16);
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
			loc2 = F924_7747(RTCW(tr1));
			RTHOOK(17);
			tr1 = *(EIF_REFERENCE *)(RTCW(loc2));
			tb3 = F1498_17608(RTCW(loc1), tr1);
			if (tb3) {
				RTHOOK(18);
				tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
				tb3 = *(EIF_BOOLEAN *)(RTCW(loc2)+ _CHROFF_1_6_);
				tb4 = *(EIF_BOOLEAN *)(RTCW(loc2)+ _CHROFF_1_7_);
				tb5 = *(EIF_BOOLEAN *)(RTCW(loc2)+ _CHROFF_1_4_);
				loc3 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE, EIF_BOOLEAN, EIF_BOOLEAN, EIF_BOOLEAN, EIF_REFERENCE)) R5434[Dtype(tr1)-443])(RTCW(tr1), loc1, tb3, tb4, tb5, NULL);
				RTHOOK(19);
				if ((EIF_BOOLEAN)(loc3 != NULL)) {
					RTHOOK(20);
					ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc2)+ _LNGOFF_1_8_0_6_);
					F1419_16702(RTCW(loc3), ti4_1);
				}
				RTHOOK(21);
				tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
				F924_7774(RTCW(tr1));
			}
			RTHOOK(22);
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
			F924_7775(RTCW(tr1));
		}
		RTHOOK(23);
		if ((EIF_BOOLEAN)(loc3 != NULL)) {
			RTHOOK(24);
			RTAR(Current, loc3);
			*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) loc3;
		} else {
			RTHOOK(25);
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
			F53_778(RTCW(tr1), loc1);
		}
	}
	RTHOOK(26);
	RTLE;
	RTEE;
}

/* {AST_FORMAL_GENERICS_PASS2}.process_generic_class_type_as */
void F317_4761 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("process_generic_class_type_as", 316, Current, 0, 1, 4633);
	RTHOOK(1);
	F317_4760(Current, arg1);
	RTHOOK(2);
	RTEE;
}

/* {AST_FORMAL_GENERICS_PASS2}.process_named_tuple_type_as */
void F317_4762 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLR(3,Current);
	RTLR(4,loc2);
	RTLIU(5);
	
	RTEAA("process_named_tuple_type_as", 316, Current, 2, 1, 4634);
	RTGC;
	
	RTHOOK(2);
	loc1 = F1417_16666(RTCW(arg1));
	RTHOOK(3);
	F924_7773(RTCW(loc1));
	for (;;) {
		RTHOOK(4);
		tb1 = F888_7590(RTCW(loc1));
		if (tb1) break;
		RTHOOK(5);
		tr1 = F924_7747(RTCW(loc1));
		tr1 = *(EIF_REFERENCE *)(RTCW(tr1) + _REFACS_1_);
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R12746[Dtype(tr1)-1349])(RTCW(tr1), Current);
		RTHOOK(6);
		if (F317_4752(Current)) {
			RTHOOK(7);
			F317_4753(Current);
			RTHOOK(8);
			tr1 = *(EIF_REFERENCE *)(Current);
			loc2 = tr1;
			if (EIF_TEST(loc2)) {
				RTHOOK(9);
				tr1 = F924_7747(RTCW(loc1));
				F1371_16270(RTCW(tr1), loc2);
			}
		}
		RTHOOK(10);
		F924_7775(RTCW(loc1));
	}
	RTHOOK(11);
	RTLE;
	RTEE;
}

/* {AST_FORMAL_GENERICS_PASS2}.process_like_id_as */
void F317_4763 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("process_like_id_as", 316, Current, 0, 1, 4635);
	RTGC;
	RTHOOK(1);
	RTLE;
	RTEE;
}

/* {AST_FORMAL_GENERICS_PASS2}.process_like_cur_as */
void F317_4764 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("process_like_cur_as", 316, Current, 0, 1, 4636);
	RTGC;
	RTHOOK(1);
	RTLE;
	RTEE;
}

/* {AST_FORMAL_GENERICS_PASS2}.process_qualified_anchored_type_as */
void F317_4765 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,arg1);
	RTLR(1,tr1);
	RTLR(2,Current);
	RTLIU(3);
	
	RTEAA("process_qualified_anchored_type_as", 316, Current, 0, 1, 4637);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R12746[Dtype(tr1)-1349])(RTCW(tr1), Current);
	RTHOOK(2);
	RTLE;
	RTEE;
}

/* {AST_FORMAL_GENERICS_PASS2}.process_type_dec_as */
void F317_4766 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,tr1);
	RTLR(2,Current);
	RTLR(3,loc1);
	RTLIU(4);
	
	RTEAA("process_type_dec_as", 316, Current, 1, 1, 4638);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R12746[Dtype(tr1)-1349])(RTCW(tr1), Current);
	RTHOOK(2);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	loc1 = tr1;
	if (EIF_TEST(loc1)) {
		RTHOOK(3);
		F1371_16270(RTCW(arg1), loc1);
	}
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {AST_FORMAL_GENERICS_PASS2}.process_none_type_as */
void F317_4767 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("process_none_type_as", 316, Current, 0, 1, 4639);
	RTGC;
	RTHOOK(1);
	RTLE;
	RTEE;
}

void EIF_Minit267 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C6/as267.c <==
/*
 * Code for class AST_FORMAL_GENERICS_PASS2
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "as267.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {AST_FORMAL_GENERICS_PASS2}.make */
void F312_5076 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,arg2);
	RTLR(3,arg3);
	RTLIU(4);
	
	RTEAA("make", 311, Current, 0, 3, 4907);
	RTGC;
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	RTAR(Current, arg2);
	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) arg2;
	RTHOOK(3);
	RTAR(Current, arg3);
	*(EIF_REFERENCE *)(Current + _REFACS_4_) = (EIF_REFERENCE) arg3;
	RTHOOK(7);
	RTLE;
	RTEE;
}

/* {AST_FORMAL_GENERICS_PASS2}.has_node_changed */
EIF_BOOLEAN F312_5077 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("has_node_changed", 311, Current, 0, 0, 4908);
	RTHOOK(1);
	RTHOOK(2);
	RTEE;
	return (EIF_BOOLEAN) (EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current + _REFACS_1_) != NULL);
}

/* {AST_FORMAL_GENERICS_PASS2}.consume_node */
void F312_5078 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("consume_node", 311, Current, 0, 0, 4909);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) NULL;
	RTHOOK(5);
	RTLE;
	RTEE;
}

/* {AST_FORMAL_GENERICS_PASS2}.process_formal_as */
void F312_5084 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("process_formal_as", 311, Current, 0, 1, 4898);
	RTGC;
	
	RTHOOK(2);
	RTLE;
	RTEE;
}

/* {AST_FORMAL_GENERICS_PASS2}.process_class_type_as */
void F312_5085 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN tb3;
	EIF_BOOLEAN tb4;
	EIF_BOOLEAN tb5;
	RTLD;
	
	RTLI(8);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,loc4);
	RTLR(3,tr1);
	RTLR(4,Current);
	RTLR(5,loc5);
	RTLR(6,loc2);
	RTLR(7,loc3);
	RTLIU(8);
	
	RTEAA("process_class_type_as", 311, Current, 5, 1, 4899);
	RTGC;
	
	RTHOOK(2);
	loc1 = *(EIF_REFERENCE *)(RTCW(arg1));
	RTHOOK(3);
	tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R22416[Dtype(RTCW(arg1))-2342])(arg1);
	loc4 = tr1;
	if (EIF_TEST(loc4)) {
		RTHOOK(4);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
		F46_529(RTCW(tr1), loc1);
		RTHOOK(5);
		F1147_10822(loc4);
		for (;;) {
			RTHOOK(6);
			tb1 = F929_9193(loc4);
			if (tb1) break;
			RTHOOK(7);
			tr1 = F1147_10796(loc4);
			(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R21906[Dtype(RTCW(tr1))-2271])(tr1, Current);
			RTHOOK(8);
			if (F312_5077(Current)) {
				RTHOOK(9);
				F312_5078(Current);
				RTHOOK(10);
				tr1 = *(EIF_REFERENCE *)(Current);
				loc5 = tr1;
				if (EIF_TEST(loc5)) {
					RTHOOK(11);
					F1147_10835(loc4, loc5);
				}
				
			}
			RTHOOK(13);
			F1147_10824(loc4);
		}
	} else {
		RTHOOK(14);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
		F1147_10822(RTCW(tr1));
		for (;;) {
			RTHOOK(15);
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
			tb2 = F929_9193(RTCW(tr1));
			if (tb2) break;
			RTHOOK(16);
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
			loc2 = F1147_10796(RTCW(tr1));
			RTHOOK(17);
			tr1 = *(EIF_REFERENCE *)(RTCW(loc2));
			tb3 = F2422_29751(RTCW(loc1), tr1);
			if (tb3) {
				RTHOOK(18);
				tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
				tb3 = *(EIF_BOOLEAN *)(RTCW(loc2)+ _CHROFF_1_6_);
				tb4 = *(EIF_BOOLEAN *)(RTCW(loc2)+ _CHROFF_1_7_);
				tb5 = *(EIF_BOOLEAN *)(RTCW(loc2)+ _CHROFF_1_4_);
				loc3 = F555_7347(RTCW(tr1), loc1, tb3, tb4, tb5, NULL);
				RTHOOK(19);
				if ((EIF_BOOLEAN)(loc3 != NULL)) {
					RTHOOK(20);
					ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc2)+ _LNGOFF_1_8_0_6_);
					F2341_28822(RTCW(loc3), ti4_1);
				}
				RTHOOK(21);
				tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
				F1147_10823(RTCW(tr1));
			}
			RTHOOK(22);
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
			F1147_10824(RTCW(tr1));
		}
		RTHOOK(23);
		if ((EIF_BOOLEAN)(loc3 != NULL)) {
			RTHOOK(24);
			RTAR(Current, loc3);
			*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) loc3;
		} else {
			RTHOOK(25);
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
			F46_529(RTCW(tr1), loc1);
		}
	}
	RTHOOK(26);
	RTLE;
	RTEE;
}

/* {AST_FORMAL_GENERICS_PASS2}.process_generic_class_type_as */
void F312_5086 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("process_generic_class_type_as", 311, Current, 0, 1, 4900);
	RTHOOK(1);
	F312_5085(Current, arg1);
	RTHOOK(2);
	RTEE;
}

/* {AST_FORMAL_GENERICS_PASS2}.process_named_tuple_type_as */
void F312_5087 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLR(3,Current);
	RTLR(4,loc2);
	RTLIU(5);
	
	RTEAA("process_named_tuple_type_as", 311, Current, 2, 1, 4901);
	RTGC;
	
	RTHOOK(2);
	loc1 = F2340_28798(RTCW(arg1));
	RTHOOK(3);
	F1147_10822(RTCW(loc1));
	for (;;) {
		RTHOOK(4);
		tb1 = F929_9193(RTCW(loc1));
		if (tb1) break;
		RTHOOK(5);
		tr1 = F1147_10796(RTCW(loc1));
		tr1 = *(EIF_REFERENCE *)(RTCW(tr1) + _REFACS_1_);
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R21906[Dtype(RTCW(tr1))-2271])(tr1, Current);
		RTHOOK(6);
		if (F312_5077(Current)) {
			RTHOOK(7);
			F312_5078(Current);
			RTHOOK(8);
			tr1 = *(EIF_REFERENCE *)(Current);
			loc2 = tr1;
			if (EIF_TEST(loc2)) {
				RTHOOK(9);
				tr1 = F1147_10796(RTCW(loc1));
				F2293_28390(RTCW(tr1), loc2);
			}
		}
		RTHOOK(10);
		F1147_10824(RTCW(loc1));
	}
	RTHOOK(11);
	RTLE;
	RTEE;
}

/* {AST_FORMAL_GENERICS_PASS2}.process_like_id_as */
void F312_5088 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("process_like_id_as", 311, Current, 0, 1, 4902);
	RTGC;
	RTHOOK(1);
	RTLE;
	RTEE;
}

/* {AST_FORMAL_GENERICS_PASS2}.process_like_cur_as */
void F312_5089 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("process_like_cur_as", 311, Current, 0, 1, 4903);
	RTGC;
	RTHOOK(1);
	RTLE;
	RTEE;
}

/* {AST_FORMAL_GENERICS_PASS2}.process_qualified_anchored_type_as */
void F312_5090 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,arg1);
	RTLR(1,tr1);
	RTLR(2,Current);
	RTLIU(3);
	
	RTEAA("process_qualified_anchored_type_as", 311, Current, 0, 1, 4904);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R21906[Dtype(RTCW(tr1))-2271])(tr1, Current);
	RTHOOK(2);
	RTLE;
	RTEE;
}

/* {AST_FORMAL_GENERICS_PASS2}.process_type_dec_as */
void F312_5091 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,tr1);
	RTLR(2,Current);
	RTLR(3,loc1);
	RTLIU(4);
	
	RTEAA("process_type_dec_as", 311, Current, 1, 1, 4905);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R21906[Dtype(RTCW(tr1))-2271])(tr1, Current);
	RTHOOK(2);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	loc1 = tr1;
	if (EIF_TEST(loc1)) {
		RTHOOK(3);
		F2293_28390(RTCW(arg1), loc1);
	}
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {AST_FORMAL_GENERICS_PASS2}.process_none_type_as */
void F312_5092 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("process_none_type_as", 311, Current, 0, 1, 4906);
	RTGC;
	RTHOOK(1);
	RTLE;
	RTEE;
}

void EIF_Minit267 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
